@@ -4,112 +4,12 @@ use 5.016;
 use warnings;
 
 package Proch::N50;
-$Proch::N50::VERSION = '0.02';
+$Proch::N50::VERSION = '0.03';
 
 use File::Basename;
 use Exporter qw(import);
-our @EXPORT = qw(getStats getN50);
+our @EXPORT = qw(getStats getN50 jsonStats);
 
-=head1 NAME
-
-B<Proch::N50> - a small module to calculate N50 (total size, and total number of
-sequences) for a FASTA or FASTQ file. It's small and without dependencies.
-
-=head1 SYNOPSIS
-
-  use Proch::N50 qw(getStats getN50);
-  my $filepath = '/path/to/assembly.fasta';
-
-  # Get N50 only
-  say "N50 only:\t" ,getN50($filepath);
-
-  # Full stats
-  my $seq_stats = getStats($filepath);
-  say Data::Dumper->Dump( [ $seq_stats ], [ qw(*FASTA_stats) ] );
-
-=head1 METHODS
-
-=head2 getN50(filepath)
-
-This function returns the N50 for a FASTA/FASTQ file given, or 0 in case of error(s).
-
-=head2 getStats(filepath, alsoJSON)
-
-Calculates N50 and basic stats for <filepath>. Returns also JSON if invoked
-with a second parameter.
-This function return a hash reporting:
-
-=over 4
-
-=item I<size> (int)
-
-total number of bp in the files
-
-=back
-
-=over 4
-
-=item I<N50> (int)
-
-the actual N50
-
-=back
-
-=over 4
-
-=item I<seqs> (int)
-
-total number of sequences in the files
-
-=back
-
-=over 4
-
-=item I<filename> (string)
-
-file basename of the input file
-
-=back
-
-=over 4
-
-=item I<dirname> (string)
-
-name of the directory containing the input file
-
-=back
-
-=over 4
-
-=item L<json> (string: JSON pretty printed)
-
-JSON string of the object (only if JSON is installed)
-
-=back
-
-=head1 Dependencies
-
-=over 4
-
-=item L<JSON> (optional)
-
-=back
-
-=over 4
-
-=item L<Term::ANSIColor> (optional; for a demo script)
-
-=back
-
-=head1 AUTHOR
-
-Andrea Telatin <andrea@telatin.com>, Quadram Institute Bioscience
-
-=head1 COPYRIGHT AND LICENSE
-
-This free software under MIT licence. No warranty, explicit or implicit, is provided.
-
-=cut
 
 my $hasJSON = 0;
 
@@ -143,7 +43,15 @@ sub getN50 {
         return 0;
     }
 }
-
+sub jsonStats {
+  my ($file) = @_;
+  my $stats = getStats($file,  'JSON');
+  if ($stats->{status} and $stats->{json}) {
+    return $stats->{json}
+  } else {
+    return undef;
+  }
+}
 sub getStats {
 
     # Parses a FASTA/FASTQ file and returns stats
@@ -246,3 +154,157 @@ sub _readfq {
 }
 
 1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Proch::N50 - Calculate N50 from a FASTA or FASTQ file without dependencies
+
+=head1 VERSION
+
+version 0.03
+
+=head1 SYNOPSIS
+
+  use Proch::N50 qw(getStats getN50);
+  my $filepath = '/path/to/assembly.fasta';
+
+  # Get N50 only: getN50(file) will return an integer
+  print "N50 only:\t", getN50($filepath), "\n";
+
+  # Full stats
+  my $seq_stats = getStats($filepath);
+  print Data::Dumper->Dump( [ $seq_stats ], [ qw(*FASTA_stats) ] );
+  # Will print:
+  # %FASTA_stats = (
+  #               'N50' => 65,
+  #               'dirname' => 'data',
+  #               'size' => 130,
+  #               'seqs' => 6,
+  #               'filename' => 'small_test.fa',
+  #               'status' => 1
+  #             );
+
+  # Get also a JSON object
+  my $seq_stats_with_JSON = getStats($filepath, 'JSON');
+  print $seq_stats_with_JSON->{json}, "\n";
+  # Will print:
+  # {
+  #    "seqs" : 6,
+  #    "status" : 1,
+  #    "filename" : "small_test.fa",
+  #    "N50" : "65",
+  #    "dirname" : "data",
+  #    "size" : 130
+  # }
+
+=head1 NAME
+
+B<Proch::N50> - a small module to calculate N50 (total size, and total number of
+sequences) for a FASTA or FASTQ file. It's small and without dependencies.
+
+=head1 METHODS
+
+=head2 getN50(filepath)
+
+This function returns the N50 for a FASTA/FASTQ file given, or 0 in case of error(s).
+
+=head2 getStats(filepath, alsoJSON)
+
+Calculates N50 and basic stats for <filepath>. Returns also JSON if invoked
+with a second parameter.
+This function return a hash reporting:
+
+=over 4
+
+=item I<size> (int)
+
+total number of bp in the files
+
+=back
+
+=over 4
+
+=item I<N50> (int)
+
+the actual N50
+
+=back
+
+=over 4
+
+=item I<seqs> (int)
+
+total number of sequences in the files
+
+=back
+
+=over 4
+
+=item I<filename> (string)
+
+file basename of the input file
+
+=back
+
+=over 4
+
+=item I<dirname> (string)
+
+name of the directory containing the input file
+
+=back
+
+=over 4
+
+=item I<json> (string: JSON pretty printed)
+
+(pretty printed) JSON string of the object (only if JSON is installed)
+
+=back
+
+=head2 jsonStats(filepath)
+
+Returns the JSON string with basic stats (same as $result->{json} from I<getStats>(File, JSON)).
+Requires JSON installed.
+
+=head1 Dependencies
+
+=over 4
+
+=item L<JSON> (optional)
+
+=back
+
+=over 4
+
+=item L<Term::ANSIColor> (optional; for a demo script)
+
+=back
+
+=head1 AUTHOR
+
+Andrea Telatin <andrea@telatin.com>, Quadram Institute Bioscience
+
+=head1 COPYRIGHT AND LICENSE
+
+This free software under MIT licence. No warranty, explicit or implicit, is provided.
+
+=head1 AUTHOR
+
+Andrea Telatin <andrea.telatin@quadram.ac.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2019 by Andrea Telatin.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
+
+=cut
